#############
Config Module
#############

.. currentmodule:: ovh.config

.. automodule:: ovh.config

.. autoclass:: ConfigurationManager

Methods
=======

__init__
--------

.. automethod:: ConfigurationManager.__init__

get
---

.. automethod:: ConfigurationManager.get

Globals
=======

.. autodata:: ovh.config.CONFIG_PATH
             :annotation:
.. autodata:: ovh.config.config
             :annotation:
